==> juffed-debuginfo-0.10-2.tar.xz: usr/src/debug/juffed-0.10-2/plugins/findinfiles/qrc_findinfiles.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/juffed/juffed-0.10-2.i686/src/juffed-0.10/plugins/findinfiles/process-stop.png
  0x0,0x0,0x3,0x34,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,
  0xa7,0x93,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,
  0xb,0x13,0x1,0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,
  0xd5,0xa,0x11,0x17,0x2d,0xd,0x6b,0xc0,0x9c,0xc0,0x0,0x0,0x2,0xc1,0x49,0x44,
  0x41,0x54,0x38,0xcb,0x6d,0x93,0xbb,0x4f,0x53,0x61,0x18,0x87,0x9f,0x73,0xe9,0x5,
  0x6d,0x8d,0xc6,0xc8,0xe0,0x25,0x86,0xc6,0x40,0x2b,0x78,0x69,0x6a,0xb8,0x9,0xa9,
  0x36,0x88,0x9a,0x98,0x90,0xb8,0xb1,0x10,0x58,0xfc,0xf,0x5c,0x3a,0x38,0x18,0x69,
  0x1c,0x1c,0x4c,0x1c,0x8c,0xb,0x71,0xd0,0xc1,0xbb,0x31,0xb8,0x98,0x50,0x24,0x9a,
  0xb0,0x88,0xc1,0xc4,0xe,0xe,0x28,0xb5,0xd4,0x16,0x4a,0x69,0xa1,0x7,0xe1,0xb4,
  0xe7,0x3b,0x9f,0x3,0xa5,0x82,0xf2,0x26,0x5f,0xbe,0xe4,0x4d,0x9e,0xdf,0x7b,0xf9,
  0xe5,0x55,0xd8,0x12,0x8f,0xc2,0x61,0x3d,0x3d,0x31,0xf1,0x44,0xc0,0x55,0x76,0x8,
  0xd,0xc6,0x4,0x5c,0x8e,0x42,0x65,0x33,0xa7,0xfc,0x3,0x3f,0x6b,0xf4,0xf9,0x2e,
  0x5d,0xbc,0x76,0xcd,0xad,0x68,0x1a,0x0,0x52,0x4a,0x10,0x2,0x69,0x59,0x7c,0x78,
  0xf8,0xd0,0xfc,0x32,0x33,0xf3,0x5e,0xc0,0x95,0x28,0x58,0x35,0x81,0x2a,0xfc,0xc2,
  0xef,0xf3,0xf5,0x46,0x86,0x86,0xdc,0xf3,0xe3,0xe3,0x98,0xf9,0xfc,0xb6,0xea,0x4e,
  0xaf,0x97,0xfa,0x8e,0xe,0x3e,0x3c,0x7d,0x6a,0x26,0x92,0xc9,0x31,0x1,0x7d,0x51,
  0xb0,0xb4,0x91,0x50,0xc8,0x91,0x9d,0x9c,0x7c,0x19,0x38,0x76,0xac,0x37,0x32,0x38,
  0xb8,0x1,0xaf,0xae,0x82,0x65,0x6d,0x13,0x10,0xaa,0xca,0x5a,0x3a,0x4d,0x20,0x12,
  0xd1,0x57,0xe7,0xe6,0x8e,0x2c,0x95,0x4a,0x67,0x6,0xc3,0xe1,0xe7,0x5a,0x67,0x26,
  0xf3,0xe6,0x78,0x63,0x63,0xcf,0xf9,0x81,0x1,0x77,0x36,0x1e,0xc7,0xaa,0xaf,0x47,
  0x8f,0xc5,0x20,0x99,0x44,0x66,0xb3,0x1b,0xb3,0x9f,0x38,0xc1,0xde,0xbb,0x77,0xa9,
  0x24,0x12,0x18,0x5f,0xbf,0x72,0x3c,0x1c,0xd6,0x8d,0x54,0xea,0xe8,0x8f,0x44,0x22,
  0xa8,0xf5,0xa8,0xea,0xe3,0xfe,0xeb,0xd7,0xf5,0xcc,0xbb,0x77,0x94,0xb,0x5,0xd4,
  0xbe,0x3e,0xd4,0x96,0x16,0x94,0x8e,0xe,0xf8,0xfe,0x1d,0x75,0xff,0x7e,0xf6,0xc,
  0xf,0xe3,0xda,0xb7,0xf,0x45,0x4a,0x4a,0xe3,0xe3,0xfc,0x2e,0x14,0x68,0xe,0x87,
  0xf5,0xa9,0xcf,0x9f,0x3,0xba,0xa2,0x28,0x20,0x25,0xe5,0x42,0x61,0xa3,0xd5,0x91,
  0x11,0x70,0xb9,0x70,0xf5,0xf6,0xe2,0xbe,0x71,0x3,0x5d,0x51,0x70,0x7a,0x3c,0x98,
  0xf1,0x38,0xf9,0x3b,0x77,0xb0,0x81,0x75,0xc3,0x40,0xa,0x81,0x2,0xa8,0xff,0x79,
  0x25,0x25,0xe2,0xfe,0x7d,0xe4,0xd4,0x14,0xce,0x5d,0xbb,0x70,0x7a,0xbd,0x58,0xd3,
  0xd3,0xe4,0x62,0x31,0x84,0x6d,0x63,0x3,0x36,0x20,0xab,0x3b,0x52,0x77,0xf4,0xbb,
  0xb9,0x19,0x77,0x28,0x84,0xae,0xeb,0x38,0x1c,0xe,0x76,0x7,0x83,0xd4,0x85,0x42,
  0xc8,0x2a,0x2c,0xca,0x65,0xc4,0xdc,0xdc,0x5f,0x1,0x29,0x44,0xd,0x56,0x5b,0x5a,
  0xf0,0xde,0xba,0x85,0xd3,0xeb,0x65,0x3d,0x1e,0x67,0x75,0x74,0x14,0xa7,0xc7,0x83,
  0xef,0xde,0x3d,0x3c,0xed,0xed,0x98,0xb9,0x1c,0xc6,0xb7,0x6f,0xc8,0x95,0x15,0x0,
  0x74,0x29,0xe5,0x86,0x9a,0x61,0x20,0x2c,0x8b,0xba,0xb6,0x36,0x5c,0x55,0x78,0x71,
  0x78,0x18,0xdb,0x34,0xd1,0x80,0x3,0xfd,0xfd,0xd4,0x9d,0x3a,0xc5,0xfa,0x83,0x7,
  0xa0,0x69,0xd8,0xd5,0xa2,0xda,0x5,0x29,0xbb,0x2b,0xc5,0xe2,0xe1,0x40,0x5b,0x9b,
  0x56,0x4a,0x24,0x28,0xbd,0x7e,0x4d,0xe5,0xe7,0x4f,0x16,0x6e,0xde,0xa4,0x9c,0xc9,
  0x50,0x5e,0x5c,0x24,0xf7,0xea,0x15,0x6b,0xb3,0xb3,0x24,0x6f,0xdf,0x46,0xd1,0x34,
  0x7c,0x7e,0x3f,0xe9,0xa5,0x25,0xfb,0xc7,0xf2,0x72,0x5e,0x89,0x81,0x53,0x83,0xb7,
  0x27,0x1b,0x1a,0xba,0x5b,0x83,0x41,0x57,0x2a,0x1e,0x67,0xad,0x58,0xac,0x2d,0x6b,
  0xeb,0x53,0x1c,0xe,0x1a,0x9a,0x9a,0x48,0x17,0xa,0xe2,0x63,0x3a,0xbd,0x60,0x43,
  0xa7,0x36,0x6,0x22,0x2,0x4f,0x72,0xc5,0x62,0x97,0x69,0x18,0x87,0x2,0xad,0xad,
  0x7a,0x69,0x7e,0x9e,0x8a,0x69,0x6e,0x83,0x55,0x87,0x83,0x6,0xbf,0x9f,0xd9,0x7c,
  0x5e,0x4c,0xfe,0xfa,0x95,0xb2,0xa1,0x3d,0xa,0xa9,0xda,0x31,0x6d,0x76,0xe2,0x3f,
  0x78,0xb0,0xfb,0xec,0xe9,0xd3,0x2e,0x45,0x8,0x6c,0xcb,0x42,0x5a,0x56,0xed,0x4f,
  0x24,0x93,0xd6,0xa7,0x6c,0x76,0xc6,0x86,0xae,0x28,0x2c,0x6e,0xbb,0xc6,0xad,0x22,
  0x2,0x7a,0x76,0xb2,0x57,0x85,0x69,0x1b,0xce,0x45,0x61,0x79,0x33,0xf7,0x7,0xc7,
  0x4d,0x52,0xf6,0xd7,0x86,0xf7,0x14,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,
  0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // stop
  0x0,0x4,
  0x0,0x7,0xab,0x60,
  0x0,0x73,
  0x0,0x74,0x0,0x6f,0x0,0x70,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/stop
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_findinfiles)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_findinfiles))

int QT_MANGLE_NAMESPACE(qCleanupResources_findinfiles)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_findinfiles))

==> juffed-debuginfo-0.10-3.tar.xz: usr/src/debug/juffed-0.10-3/plugins/findinfiles/qrc_findinfiles.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/juffed/juffed-0.10-3.x86_64/src/juffed-0.10/plugins/findinfiles/process-stop.png
  0x0,0x0,0x3,0x34,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,
  0xa7,0x93,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,
  0xb,0x13,0x1,0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,
  0xd5,0xa,0x11,0x17,0x2d,0xd,0x6b,0xc0,0x9c,0xc0,0x0,0x0,0x2,0xc1,0x49,0x44,
  0x41,0x54,0x38,0xcb,0x6d,0x93,0xbb,0x4f,0x53,0x61,0x18,0x87,0x9f,0x73,0xe9,0x5,
  0x6d,0x8d,0xc6,0xc8,0xe0,0x25,0x86,0xc6,0x40,0x2b,0x78,0x69,0x6a,0xb8,0x9,0xa9,
  0x36,0x88,0x9a,0x98,0x90,0xb8,0xb1,0x10,0x58,0xfc,0xf,0x5c,0x3a,0x38,0x18,0x69,
  0x1c,0x1c,0x4c,0x1c,0x8c,0xb,0x71,0xd0,0xc1,0xbb,0x31,0xb8,0x98,0x50,0x24,0x9a,
  0xb0,0x88,0xc1,0xc4,0xe,0xe,0x28,0xb5,0xd4,0x16,0x4a,0x69,0xa1,0x7,0xe1,0xb4,
  0xe7,0x3b,0x9f,0x3,0xa5,0x82,0xf2,0x26,0x5f,0xbe,0xe4,0x4d,0x9e,0xdf,0x7b,0xf9,
  0xe5,0x55,0xd8,0x12,0x8f,0xc2,0x61,0x3d,0x3d,0x31,0xf1,0x44,0xc0,0x55,0x76,0x8,
  0xd,0xc6,0x4,0x5c,0x8e,0x42,0x65,0x33,0xa7,0xfc,0x3,0x3f,0x6b,0xf4,0xf9,0x2e,
  0x5d,0xbc,0x76,0xcd,0xad,0x68,0x1a,0x0,0x52,0x4a,0x10,0x2,0x69,0x59,0x7c,0x78,
  0xf8,0xd0,0xfc,0x32,0x33,0xf3,0x5e,0xc0,0x95,0x28,0x58,0x35,0x81,0x2a,0xfc,0xc2,
  0xef,0xf3,0xf5,0x46,0x86,0x86,0xdc,0xf3,0xe3,0xe3,0x98,0xf9,0xfc,0xb6,0xea,0x4e,
  0xaf,0x97,0xfa,0x8e,0xe,0x3e,0x3c,0x7d,0x6a,0x26,0x92,0xc9,0x31,0x1,0x7d,0x51,
  0xb0,0xb4,0x91,0x50,0xc8,0x91,0x9d,0x9c,0x7c,0x19,0x38,0x76,0xac,0x37,0x32,0x38,
  0xb8,0x1,0xaf,0xae,0x82,0x65,0x6d,0x13,0x10,0xaa,0xca,0x5a,0x3a,0x4d,0x20,0x12,
  0xd1,0x57,0xe7,0xe6,0x8e,0x2c,0x95,0x4a,0x67,0x6,0xc3,0xe1,0xe7,0x5a,0x67,0x26,
  0xf3,0xe6,0x78,0x63,0x63,0xcf,0xf9,0x81,0x1,0x77,0x36,0x1e,0xc7,0xaa,0xaf,0x47,
  0x8f,0xc5,0x20,0x99,0x44,0x66,0xb3,0x1b,0xb3,0x9f,0x38,0xc1,0xde,0xbb,0x77,0xa9,
  0x24,0x12,0x18,0x5f,0xbf,0x72,0x3c,0x1c,0xd6,0x8d,0x54,0xea,0xe8,0x8f,0x44,0x22,
  0xa8,0xf5,0xa8,0xea,0xe3,0xfe,0xeb,0xd7,0xf5,0xcc,0xbb,0x77,0x94,0xb,0x5,0xd4,
  0xbe,0x3e,0xd4,0x96,0x16,0x94,0x8e,0xe,0xf8,0xfe,0x1d,0x75,0xff,0x7e,0xf6,0xc,
  0xf,0xe3,0xda,0xb7,0xf,0x45,0x4a,0x4a,0xe3,0xe3,0xfc,0x2e,0x14,0x68,0xe,0x87,
  0xf5,0xa9,0xcf,0x9f,0x3,0xba,0xa2,0x28,0x20,0x25,0xe5,0x42,0x61,0xa3,0xd5,0x91,
  0x11,0x70,0xb9,0x70,0xf5,0xf6,0xe2,0xbe,0x71,0x3,0x5d,0x51,0x70,0x7a,0x3c,0x98,
  0xf1,0x38,0xf9,0x3b,0x77,0xb0,0x81,0x75,0xc3,0x40,0xa,0x81,0x2,0xa8,0xff,0x79,
  0x25,0x25,0xe2,0xfe,0x7d,0xe4,0xd4,0x14,0xce,0x5d,0xbb,0x70,0x7a,0xbd,0x58,0xd3,
  0xd3,0xe4,0x62,0x31,0x84,0x6d,0x63,0x3,0x36,0x20,0xab,0x3b,0x52,0x77,0xf4,0xbb,
  0xb9,0x19,0x77,0x28,0x84,0xae,0xeb,0x38,0x1c,0xe,0x76,0x7,0x83,0xd4,0x85,0x42,
  0xc8,0x2a,0x2c,0xca,0x65,0xc4,0xdc,0xdc,0x5f,0x1,0x29,0x44,0xd,0x56,0x5b,0x5a,
  0xf0,0xde,0xba,0x85,0xd3,0xeb,0x65,0x3d,0x1e,0x67,0x75,0x74,0x14,0xa7,0xc7,0x83,
  0xef,0xde,0x3d,0x3c,0xed,0xed,0x98,0xb9,0x1c,0xc6,0xb7,0x6f,0xc8,0x95,0x15,0x0,
  0x74,0x29,0xe5,0x86,0x9a,0x61,0x20,0x2c,0x8b,0xba,0xb6,0x36,0x5c,0x55,0x78,0x71,
  0x78,0x18,0xdb,0x34,0xd1,0x80,0x3,0xfd,0xfd,0xd4,0x9d,0x3a,0xc5,0xfa,0x83,0x7,
  0xa0,0x69,0xd8,0xd5,0xa2,0xda,0x5,0x29,0xbb,0x2b,0xc5,0xe2,0xe1,0x40,0x5b,0x9b,
  0x56,0x4a,0x24,0x28,0xbd,0x7e,0x4d,0xe5,0xe7,0x4f,0x16,0x6e,0xde,0xa4,0x9c,0xc9,
  0x50,0x5e,0x5c,0x24,0xf7,0xea,0x15,0x6b,0xb3,0xb3,0x24,0x6f,0xdf,0x46,0xd1,0x34,
  0x7c,0x7e,0x3f,0xe9,0xa5,0x25,0xfb,0xc7,0xf2,0x72,0x5e,0x89,0x81,0x53,0x83,0xb7,
  0x27,0x1b,0x1a,0xba,0x5b,0x83,0x41,0x57,0x2a,0x1e,0x67,0xad,0x58,0xac,0x2d,0x6b,
  0xeb,0x53,0x1c,0xe,0x1a,0x9a,0x9a,0x48,0x17,0xa,0xe2,0x63,0x3a,0xbd,0x60,0x43,
  0xa7,0x36,0x6,0x22,0x2,0x4f,0x72,0xc5,0x62,0x97,0x69,0x18,0x87,0x2,0xad,0xad,
  0x7a,0x69,0x7e,0x9e,0x8a,0x69,0x6e,0x83,0x55,0x87,0x83,0x6,0xbf,0x9f,0xd9,0x7c,
  0x5e,0x4c,0xfe,0xfa,0x95,0xb2,0xa1,0x3d,0xa,0xa9,0xda,0x31,0x6d,0x76,0xe2,0x3f,
  0x78,0xb0,0xfb,0xec,0xe9,0xd3,0x2e,0x45,0x8,0x6c,0xcb,0x42,0x5a,0x56,0xed,0x4f,
  0x24,0x93,0xd6,0xa7,0x6c,0x76,0xc6,0x86,0xae,0x28,0x2c,0x6e,0xbb,0xc6,0xad,0x22,
  0x2,0x7a,0x76,0xb2,0x57,0x85,0x69,0x1b,0xce,0x45,0x61,0x79,0x33,0xf7,0x7,0xc7,
  0x4d,0x52,0xf6,0xd7,0x86,0xf7,0x14,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,
  0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // stop
  0x0,0x4,
  0x0,0x7,0xab,0x60,
  0x0,0x73,
  0x0,0x74,0x0,0x6f,0x0,0x70,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/stop
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_findinfiles)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_findinfiles))

int QT_MANGLE_NAMESPACE(qCleanupResources_findinfiles)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_findinfiles))
